==> gimp_2.8.22.orig.tar.bz2: gimp-2.8.22/app/core/gimpdocumentlist.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995-1997 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_DOCUMENT_LIST_H__
#define __GIMP_DOCUMENT_LIST_H__

#include "core/gimplist.h"


#define GIMP_TYPE_DOCUMENT_LIST           (gimp_document_list_get_type ())
#define GIMP_DOCUMENT_LIST(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_DOCUMENT_LIST, GimpDocumentList))
#define GIMP_DOCUMENT_LIST_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_DOCUMENT_LIST, GimpDocumentListClass))
#define GIMP_IS_DOCUMENT_LIST(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_DOCUMENT_LIST))
#define GIMP_IS_DOCUMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_DOCUMENT_LIST))


typedef struct _GimpDocumentListClass GimpDocumentListClass;

struct _GimpDocumentList
{
  GimpList  parent_instance;

  Gimp     *gimp;
};

struct _GimpDocumentListClass
{
  GimpListClass  parent_class;
};


GType           gimp_document_list_get_type (void) G_GNUC_CONST;
GimpContainer * gimp_document_list_new      (Gimp             *gimp);

GimpImagefile * gimp_document_list_add_uri  (GimpDocumentList *document_list,
                                             const gchar      *uri,
                                             const gchar      *mime_type);


#endif  /*  __GIMP_DOCUMENT_LIST_H__  */

==> gimp-2.10.2.tar.bz2: gimp-2.10.2/app/core/gimpdocumentlist.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995-1997 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_DOCUMENT_LIST_H__
#define __GIMP_DOCUMENT_LIST_H__

#include "core/gimplist.h"


#define GIMP_TYPE_DOCUMENT_LIST           (gimp_document_list_get_type ())
#define GIMP_DOCUMENT_LIST(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_DOCUMENT_LIST, GimpDocumentList))
#define GIMP_DOCUMENT_LIST_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_DOCUMENT_LIST, GimpDocumentListClass))
#define GIMP_IS_DOCUMENT_LIST(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_DOCUMENT_LIST))
#define GIMP_IS_DOCUMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_DOCUMENT_LIST))


typedef struct _GimpDocumentListClass GimpDocumentListClass;

struct _GimpDocumentList
{
  GimpList  parent_instance;

  Gimp     *gimp;
};

struct _GimpDocumentListClass
{
  GimpListClass  parent_class;
};


GType           gimp_document_list_get_type (void) G_GNUC_CONST;
GimpContainer * gimp_document_list_new      (Gimp             *gimp);

GimpImagefile * gimp_document_list_add_file (GimpDocumentList *document_list,
                                             GFile            *file,
                                             const gchar      *mime_type);


#endif  /*  __GIMP_DOCUMENT_LIST_H__  */
